ResourceDartBuilder class

Constructors

ResourceDartBuilder(Config config)

Properties

allImageList → List<String>
Convert the set to the list
no setter
config → Config
final
dirList → List<Directory>
All of the directory with yaml.
final
filter → Filter?
no setter
hashCode → int
The hash code for this object.
no setterinherited
imageSet → Set<String>
The set is all file path,not exists directory.
final
isPreview → bool
no setter
isWatch → bool
no setter
isWriting → bool
final
logFile → File
no setter
outputPath → String
no setter
projectRootPath → String
no setter
resourceFile → File
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
watchMap → Map<FileSystemEntity, StreamSubscription<FileSystemEvent>?>
final

Methods

generateCode(String className) → void
Generate the dart code
generateImageFiles(List<String> paths) → void
Scan the with path list
generateImageFileWithPath(String path, Set<String> imageSet, List<Directory> dirList, bool rootPath) → void
If path is a directory, add the directory to dirList. If not, add it to imageSet.
generateResourceDartFile() → void
getListFromYamlList(YamlList yamlList) → List<String>
Get the asset from yaml list
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllWatches() → void
startWatch(String className) → Future<void>
Watch all paths
stopWatch() → void
toString() → String
A string representation of this object.
inherited
writeText(Object text, {File? file}) → void
Write logs to the file Defaults to .dart_tools/fgen_log.txt

Operators

operator ==(Object other) → bool
The equality operator.
inherited