Config class

Constructors

Config({required ArgResults results})
Config.fromArgResults(ArgResults results)
factory

Properties

className ↔ String
getter/setter pair
configFileOptions ↔ YamlMap?
getter/setter pair
filter ↔ Filter?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isWatch ↔ bool
getter/setter pair
output ↔ String
getter/setter pair
preview ↔ bool
getter/setter pair
results → ArgResults
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultPath → String
final