Replacer class

Constructors

Replacer({required Config config})

Properties

config → Config
final
hashCode → int
The hash code for this object.
no setterinherited
itemMap → Map<String, RegexItem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceName(String path) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited