Template class

Constructors

Template(String className, Config config)

Properties

classDeclare → String
no setter
classDeclareFooter → String
no setter
className → String
final
config → Config
final
hashCode → int
The hash code for this object.
no setterinherited
license ↔ String
getter/setter pair
replacer → Replacer
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatFiled(String path, String projectPath, bool isPreview) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toUppercaseFirstLetter(String str) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited